@@ -16,13 +16,13 @@
 ##'     \code{glm} or \code{coxph}.
 ##' @param param.method Method to obtain model coefficients.
 ##' @param confint.method Method to obtain confidence
-##'     intervals. Default is \code{'default'} which leads to Wald
+##'     intervals. Default is 'default' which leads to Wald
 ##'     type intervals using the model based estimate of standard
-##'     error.  \code{'profile'} yields profile likelihood confidence
+##'     error. 'profile' yields profile likelihood confidence
 ##'     intervals, available from library MASS for \code{lm} and
-##'     \code{glm} objects. \code{'robust'} uses the sandwich form
+##'     \code{glm} objects. 'robust' uses the sandwich form
 ##'     standard error to construct Wald type intervals (see
-##'     \code{lava::estimate.default}). \code{simultaneous} calls
+##'     \code{lava::estimate.default}). 'simultaneous' calls
 ##'     \code{multcomp::glht} to obtain simultaneous confidence
 ##'     intervals.
 ##' @param pvalue.method Method to obtain p-values. If
@@ -279,7 +279,7 @@ regressionTable <- function(object,
         if (vn=="Intercept"||vn=="(Intercept)")
             Missing <- ""
         else
-            Missing <- try(eval(parse(text=misscall),data))
+            Missing <- try(eval(parse(text=misscall),data),silent=TRUE)
         if (class(Missing)[1]=="try-error") Missing <- NA
         # }}}
         if (isfactor){
